// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Linq;
using System.Drawing;
using System.Collections.Generic;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Svg;
using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Text;

namespace DsPdfWeb.Demos.Basics
{
    // このサンプルでは、フォントが埋め込まれていない既存の PDF を、
    // フォントが埋め込まれた PDF に変換する方法を紹介しています。
    public class AddEmbeddedFonts
    {
        public int CreatePDF(Stream stream)
        {
            // フォントが埋め込まれていない PDF を読み込みます。
            using var fs = File.OpenRead(Path.Combine("Resources", "PDFs", "CompleteJavaScriptBook-nofonts.pdf"));
            var docSrc = new GcPdfDocument();
            docSrc.Load(fs);

            // 新しいドキュメントを作成し、元の PDF の各ページをその中に描画します。
            var doc = new GcPdfDocument();
            // 以下のコードにてフォントの埋め込みモードを設定できます。新しく作成した GcPdfDocument では、
            // EmbedSubset がデフォルトの埋め込みモードのため、このサンプルでは実際には必要ありません。
            // doc.FontEmbedMode = FontEmbedMode.EmbedSubset;
            foreach (var p in docSrc.Pages)
            {
                var pNew = doc.NewPage();
                pNew.Size = p.Size;
                pNew.Graphics.DrawPdfPage(p, p.Bounds);
            }

            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
